# this code picks up where Part 1 left off
count_table <- read.csv("GSE62902.csv", row.names = 1) # read data
alignment_subset <- count_table[39181:39185, ] # figure out which are the pesky last rows
count_table <- count_table[-(39181:39185), ] # keep only the non-pesky rows
dosage <- count_table[1, ] # save dosage as its own object
count_table <- count_table[-1, ] # now remove dosage, because it's not a sequencing count

install.packages("preprocessCore") # need only do once for R version
library(preprocessCore) # need only do once for R session

dosage[dosage==0]<-0.003 # I'll eventually take logs, so can't have zero
log10dose<-log10(as.numeric(dosage)) # I like the log scale for dose
X<-as.matrix(count_table)+0.5 # to make sure it's a matrix, +.5 to zero-protect
Xnorm1<-log10(t(t(X)/colSums(X))) # tricky, divide by column sums and take logs
Xnorm2<-normalize.quantiles(Xnorm1) # quantile normalization, "final" expression data
#Xnorm2<-data.frame(Xnorm2) # data frame has some nice properties
colnames(Xnorm2)<-colnames(X) # but now we should add the column names back
rownames(Xnorm2)<-rownames(X) # and we should add the row names back

hist(Xnorm2[,1]) # histogram of the first column
hist(Xnorm2$GSM1535917)# won't work because Xnorm2 is not a data frame
hist(Xnorm2,col="yellow") # color!
par(mfrow=c(2,2)) # sets "parameters" for plotting, in this case 2*2 rows/columns plotting
hist(Xnorm2[1,],col=1) # first row=first gene
hist(Xnorm2[2,],col=2) # why did it do that?
hist(Xnorm2[3,],col=3)
hist(Xnorm2[4,],col=4)

boxplot(Xnorm1) # a boxplot
boxplot(Xnorm2) # reflects normalization
dev.off() # turn off graphics device

summary(Xnorm2[,1]) # summarizes basic stats
summary(Xnorm2[1,])
print(mean(Xnorm2)) # the mean. try sd,, median, etc.

plot(Xnorm2[,2],Xnorm2[,30]) # mouse 2 vs. mouse 30
abline(0,1,col=2) # col=2 means "red"
identify(Xnorm2[,2],Xnorm2[,30]) # click near points and then to console, hit escape

plot(log10dose,Xnorm2[4305,]) # gene 4305 vs. log10dose
plot(log10dose,Xnorm2[4305,],pch=16,col="blue")
plot(log10dose,Xnorm2[4305,],pch=16,col="blue",cex=1.5)
plot(log10dose,Xnorm2[4305,],pch=16,col="blue",cex=1.5,ylab="normalized expression",main="My plot!")

mylm<-lm(Xnorm2[4305,]~log10dose) # fit linear model
summary(mylm) # shows what's in mylm
abline(mylm) # add overlay line

log10dose.2<-log10dose^2 # squared term
mylm<-lm(Xnorm2[4305,]~log10dose+log10dose.2) # fit again, now with quadratic term
points(log10dose,mylm$fitted.values,col=2,pch=3) # overlay fitted values
points(log10dose,mylm$fitted.values,col=2,pch=3,lwd=3) # overlay fittted values, thicker


t.test(Xnorm2[4305,dosage==0.003],Xnorm2[4305,dosage==30]) # t-test of two groups at extremes
?t.test

myaov<-aov(Xnorm2[4305,]~dosage) # analysis of variance. what's wrong?
myaov<-aov(Xnorm2[4305,]~as.factor(dosage)) # okay now it works
summary(myaov) # results

mypca<-prcomp(t(Xnorm2)) #PCA, we use t() to turn data on side
summary(mypca)
str(mypca)
#https://www.datacamp.com/community/tutorials/pca-analysis-r
pairs(mypca$x[,1:3]) # pairs command does multiple pairwise scatterplots
pairs(mypca$x[,1:3],col=as.factor(dosage),pch=16) # color by dose
plot(log10dose,mypca$x[,1],pch=1) # wow! The first PC is largely driven by dose


#gratuitous plot
a <- (-440:200) / 200
b <- c(-300:300) / 200
b <- complex(length(b), 0, b)
m <- outer(a, b, FUN = "+")
magnitude.m <- sqrt(Re(m)^2 + Im(m)^2)
z <- matrix(0,length(a), length(b))
for (i in (1:20)) {
  z <- z^2 + m
}
magnitude.z <- sqrt(Re(z)^2 + Im(z)^2)
magnitude.z[is.na(magnitude.z)] <-magnitude.m[is.na(magnitude.z)]^500
image(a, Im(b), -log(magnitude.z) * (magnitude.z > 10), col = c(heat.colors(100),1))


